## 0.2.0 (2024-07-19)

### Feat

- **template**: include sha1 in template

## 0.1.1 (2024-07-19)

### Fix

- adjust package layout to allow for proper imports

## 0.1.0 (2024-07-19)

### Feat

- include commit details and footers in parsed_message dict
